/******************************************************************************
*
* Copyright (C) 2009 - 2014 Xilinx, Inc.  All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* Use of the Software is limited solely to applications:
* (a) running on a Xilinx device, or
* (b) that interact with a Xilinx device through a bus or interconnect.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* XILINX  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*
* Except as contained in this notice, the name of the Xilinx shall not be used
* in advertising or otherwise to promote the sale, use or other dealings in
* this Software without prior written authorization from Xilinx.
*
******************************************************************************/

#include <stdio.h>
#include <unistd.h>
#include "platform.h"
#include "xstatus.h"
#include "rpu_pm_common.h"

XStatus start_axi_dma_cyclic(void);
XStatus axi_dma_check(void);

const static enum XPmNodeId my_node_list[] = {
										NODE_UART_1,
										NODE_DDR,
										NODE_TTC_2,
										0/* end of the list*/};

void notify_alive(char status[])
{
	static int count = 1;
	xil_printf("R5 A (RPU_0) [Message Count: %d] ## %s\n\r", count ++, status);
}

int main()
{
#ifdef DMA_TEST
	int dma_running = 0;
#endif

    init_platform();

	sleep(3);

    if (XST_SUCCESS != Pm_initialization(my_node_list))
    {
		xil_printf("PmInit Failed\n\r");
    	return -1;
    }

    xil_printf("Starting R5 0 Application\n\r");

#ifdef DMA_TEST

    /* start dma in cyclic mode */
    if (start_axi_dma_cyclic() == XST_SUCCESS)
    {
    	dma_running = 1;
    }
#endif

    while (1) {
#ifdef DMA_TEST
    	if (dma_running)
    	{
			/* data integrity check */
			if (axi_dma_check() == XST_SUCCESS)
			{
				notify_alive("Axi DMA status: Data Check Pass\n\r");
			}
			else
			{
				notify_alive(" Axi DMA status: Data Check Failed\n\r");
			}
    	}
    	else
    	{
    		notify_alive(" Axi DMA status: Err. Not programmed\n\r");
    	}
#else
    	notify_alive("");
#endif
    	sleep(5);
    }
    cleanup_platform();
    return 0;
}
