/******************************************************************************
*
* Copyright (C) 2009 - 2014 Xilinx, Inc.  All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* Use of the Software is limited solely to applications:
* (a) running on a Xilinx device, or
* (b) that interact with a Xilinx device through a bus or interconnect.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* XILINX  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*
* Except as contained in this notice, the name of the Xilinx shall not be used
* in advertising or otherwise to promote the sale, use or other dealings in
* this Software without prior written authorization from Xilinx.
*
******************************************************************************/
/*
 * pm_common.c
 *
 *  Created on: Jun 17, 2017
 *      Author: pallavj
 */


#include <stdio.h>
#include "rpu_pm_common.h"

static XStatus IpiConfigure(XIpiPsu *const IpiInstPtr)
{
	XStatus Status;
	XIpiPsu_Config *IpiCfgPtr;

	/* Look Up the config data */
	IpiCfgPtr = XIpiPsu_LookupConfig(XPAR_XIPIPSU_0_DEVICE_ID);
	if (NULL == IpiCfgPtr) {
		Status = XST_FAILURE;
		xil_printf("%s ERROR in getting CfgPtr\n", __func__);
		return Status;
	}

	/* Init with the Cfg Data */
	Status = XIpiPsu_CfgInitialize(IpiInstPtr, IpiCfgPtr, IpiCfgPtr->BaseAddress);
	if (XST_SUCCESS != Status) {
		xil_printf("%s ERROR in configuring IPI\n", __func__);
		return Status;
	}
	return Status;
}

int Pm_initialization(const enum XPmNodeId *node_list)
{
	static XIpiPsu IpiInst;
	int Index = 0;

	if (XST_SUCCESS != IpiConfigure(&IpiInst)) {
		xil_printf("Exiting app...\n");
		return XST_FAILURE;
	}

	if (XST_SUCCESS != XPm_InitXilpm(&IpiInst)) {
		xil_printf("Exiting app...\n");
		return XST_FAILURE;
	}

	while (node_list[Index] > NODE_UNKNOWN && node_list[Index] < NODE_ID_MAX) {

		if (XST_SUCCESS != XPm_RequestNode(node_list[Index],
											PM_CAP_ACCESS, MAX_QOS,
											REQUEST_ACK_BLOCKING)) {
			xil_printf("Error requesting node %d\n", node_list[Index]);
			return XST_FAILURE;
		}

		Index++;
	}
	xil_printf("Requested %d nodes\n\r", Index);

	XPm_InitFinalize();

	return XST_SUCCESS;
}


